package com.ruoyi.app.service.impl;

import java.util.List;

import com.ruoyi.app.domain.AppGoodsPair;
import com.ruoyi.app.mapper.AppGoodsPairMapper;
import com.ruoyi.app.service.IAppGoodsPairService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2025-01-14
 */
@Service
public class AppGoodsPairServiceImpl implements IAppGoodsPairService
{
    @Autowired
    private AppGoodsPairMapper appGoodsPairMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param pairId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public AppGoodsPair selectAppGoodsPairByPairId(String pairId)
    {
        return appGoodsPairMapper.selectAppGoodsPairByPairId(pairId);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param appGoodsPair 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<AppGoodsPair> selectAppGoodsPairList(AppGoodsPair appGoodsPair)
    {
        return appGoodsPairMapper.selectAppGoodsPairList(appGoodsPair);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param appGoodsPair 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertAppGoodsPair(AppGoodsPair appGoodsPair)
    {
        return appGoodsPairMapper.insertAppGoodsPair(appGoodsPair);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param appGoodsPair 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateAppGoodsPair(AppGoodsPair appGoodsPair)
    {
        return appGoodsPairMapper.updateAppGoodsPair(appGoodsPair);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param pairIds 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteAppGoodsPairByPairIds(String[] pairIds)
    {
        return appGoodsPairMapper.deleteAppGoodsPairByPairIds(pairIds);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param pairId 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteAppGoodsPairByPairId(String pairId)
    {
        return appGoodsPairMapper.deleteAppGoodsPairByPairId(pairId);
    }
}
