package com.ruoyi.web.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.app.domain.AppGoods;
import com.ruoyi.app.domain.AppGoodsPair;
import com.ruoyi.app.service.IAppGoodsPairService;
import com.ruoyi.web.controller.section.EnhanceDataList;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2025-01-15
 */
@RestController
@RequestMapping("/app/pair")
public class AppGoodsPairController extends BaseController
{
    @Autowired
    private IAppGoodsPairService appGoodsPairService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:pair:list')")
    @GetMapping("/list")
    @EnhanceDataList(entityType = AppGoodsPair.class)
    public TableDataInfo list(AppGoodsPair appGoodsPair)
    {
        startPage();
        List<AppGoodsPair> list = appGoodsPairService.selectAppGoodsPairList(appGoodsPair);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:pair:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppGoodsPair appGoodsPair)
    {
        List<AppGoodsPair> list = appGoodsPairService.selectAppGoodsPairList(appGoodsPair);
        ExcelUtil<AppGoodsPair> util = new ExcelUtil<AppGoodsPair>(AppGoodsPair.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:pair:query')")
    @GetMapping(value = "/{pairId}")
    public AjaxResult getInfo(@PathVariable("pairId") String pairId)
    {
        return success(appGoodsPairService.selectAppGoodsPairByPairId(pairId));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:pair:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppGoodsPair appGoodsPair)
    {
        return toAjax(appGoodsPairService.insertAppGoodsPair(appGoodsPair));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:pair:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppGoodsPair appGoodsPair)
    {
        return toAjax(appGoodsPairService.updateAppGoodsPair(appGoodsPair));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:pair:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{pairIds}")
    public AjaxResult remove(@PathVariable String[] pairIds)
    {
        return toAjax(appGoodsPairService.deleteAppGoodsPairByPairIds(pairIds));
    }
}
